@@ -9,7 +9,7 @@ from .utils import style, program_exists
 
 def build(_):
     from kodb.build import build_document
-    check_program_availability()
+    check_dependencies()
     build_document()
 
 
